* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Modeling Best Practices](https://help.sap.com/docs/leanix/ea/modeling-best-practices)
  * SAP Modeling Best Practices
